@@ -23,24 +23,26 @@
 #include <unistd.h>
 #include <stdio.h>
 #include <string.h>
+#include <ctype.h>
 
+/* TODO: Figure out why this is required here */
+#define I_KNOW_RARIAN_0_8_IS_UNSTABLE
 #include "rarian-reg-full.h"
 #include "rarian-reg-utils.h"
 #include "rarian-utils.h"
 
 
-void       process_line_full (char *line, RrnRegFull *reg);
-void       process_pair_full (RrnRegFull *reg, char *key, char *value);
+static void       process_line_full (char *line, RrnRegFull *reg);
+static void       process_pair_full (RrnRegFull *reg, char *key, char *value);
 
-void     process_sect_line_full (char *line, RrnSectFull *sect);
-void     process_sect_pair_full (RrnSectFull *sect, char *key, char *value);
-int      rrn_reg_add_sect_full (RrnRegFull *reg, RrnSectFull *sect);
-RrnListEntry *rrn_full_add_field (RrnListEntry *current, char *text,
-									  char *lang);
-RrnSectFull * rrn_sect_new_full ();
-void     rrn_sect_free_full (RrnSectFull *sect);
-char *   process_path_full (RrnRegFull *reg);
-char *   process_section_path_full (RrnListEntry *owner_paths, RrnSectFull *section);
+static void     process_sect_line_full (char *line, RrnSectFull *sect);
+static void     process_sect_pair_full (RrnSectFull *sect, char *key, 
+					char *value);
+static int      rrn_reg_add_sect_full (RrnRegFull *reg, RrnSectFull *sect);
+static RrnSectFull * rrn_sect_new_full ();
+static void     rrn_sect_free_full (RrnSectFull *sect);
+static void     process_path_full (RrnRegFull *reg);
+static void     process_section_path_full (RrnListEntry *owner_paths, RrnSectFull *section);
 
 RrnRegFull *
 rrn_reg_new_full ()
@@ -59,6 +61,8 @@ rrn_reg_new_full ()
     reg->heritage    = NULL;
     reg->lang = NULL;
     reg->children = NULL;
+    
+    return reg;
 }
 
 RrnRegFull *
@@ -171,12 +175,12 @@ rrn_reg_parse_file_full (char *filename)
 
 		sep = strrchr (filename, '/');
 		last = strrchr (filename, '.');
-		if (!last || !sep) {
+		if (!last || !sep || last < sep) {
 			fprintf (stderr, "Error: Can't cut put basename properly\n");
 			rrn_reg_free_full (reg);
 			return NULL;
 		}
-		basename = rrn_strndup (last+1, sep-last+1);
+		basename = rrn_strndup (sep + 1, last - (sep + 1));
 		reg->identifier = malloc (sizeof (char)*(strlen(basename)+11));
 		sprintf (reg->identifier, "org.other.%s", basename);
 		free (basename);
@@ -189,7 +193,7 @@ rrn_reg_parse_file_full (char *filename)
     return reg;
 }
 
-void
+static void
 process_line_full (char *line, RrnRegFull *reg)
 {
 	char *ret = NULL;
@@ -217,7 +221,7 @@ process_line_full (char *line, RrnRegFull *reg)
 	return;
 }
 
-char *
+static char *
 find_language (char *key)
 {
     char *lbrace = NULL, *rbrace = NULL;
@@ -260,7 +264,7 @@ rrn_full_add_field (RrnListEntry *current, char *text, char *lang)
 
 }
 
-char **
+static char **
 process_categories_full (char *cat_string)
 {
 	char **result = NULL;
@@ -296,39 +300,43 @@ process_categories_full (char *cat_string)
 	return result;
 }
 
-void
+static void
 process_pair_full (RrnRegFull *reg, char *key, char *value)
 {
-    char *lang = NULL;
+  char *lang = NULL;
 
-    lang = find_language (key);
+  lang = find_language (key);
 
-    if (!strncmp (key, "Name", 4) || !strncmp (key, "name", 4)) {
-        reg->name = rrn_full_add_field (reg->name, value, lang);
-    } else if (!strncmp (key, "Comment", 7) || !strncmp (key, "comment", 7)) {
-        reg->comment = rrn_full_add_field (reg->comment, value, lang);
-    } else if (!strncmp (key, "DocPath", 7) || !strncmp (key, "docpath", 7)) {
-        reg->uri = rrn_full_add_field (reg->uri, value, lang);
-    } else if (!strcmp (key, "DocIdentifier") || !strcmp (key, "docidentifier")) {
-        reg->identifier = strdup (value);
-    } else if (!strcmp (key, "DocType") || !strcmp (key, "doctype")) {
-        reg->type = strdup (value);
-	} else if (!strcmp (key, "Categories") || !strcmp (key, "categories")) {
-		reg->categories = process_categories_full (value);
-	} else if (!strcmp (key, "DocWeight") || !strcmp (key, "docweight")) {
-		reg->weight = atoi (value);
-	} else if (!strcmp (key, "DocHeritage") || !strcmp (key, "docheritage")) {
-		reg->heritage = strdup (value);
-	} else if (!strcmp (key, "DocLang") || !strcmp (key, "doclang")) {
-		if (!reg->lang) {
-			reg->lang = strdup (value);
-		}
-	} else if (!strcmp (key, "Icon") || !strcmp (key, "icon")) {
-		reg->icon = strdup (value);
-    } else {
-        fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  if (!strncmp (key, "Name", 4)) {
+    reg->name = rrn_full_add_field (reg->name, value, lang);
+  } else if (!strncmp (key, "Comment", 7)) {
+    reg->comment = rrn_full_add_field (reg->comment, value, lang);
+  } else if (!strncmp (key, "DocPath", 7)) {
+    reg->uri = rrn_full_add_field (reg->uri, value, lang);
+  } else if (!strcmp (key, "DocIdentifier")) {
+    reg->identifier = strdup (value);
+  } else if (!strcmp (key, "DocType")) {
+    reg->type = strdup (value);
+  } else if (!strcmp (key, "Categories")) {
+    reg->categories = process_categories_full (value);
+  } else if (!strcmp (key, "DocWeight")) {
+    reg->weight = atoi (value);
+  } else if (!strcmp (key, "DocHeritage")) {
+    reg->heritage = strdup (value);
+  } else if (!strcmp (key, "NoDisplay")) {
+    reg->hidden = TRUE;
+  } else if (!strcmp (key, "DocDefaultSection")) {
+    reg->default_section = strdup (value);
+  } else if (!strcmp (key, "DocLang")) {
+    if (!reg->lang) {
+      reg->lang = strdup (value);
     }
-    return;
+  } else if (!strcmp (key, "Icon")){
+    reg->icon = strdup (value);
+  } else {
+    fprintf (stderr, "WARNING: Unknown element %s: %s\n", key, value);
+  }
+  return;
 }
 
 void
@@ -377,7 +385,7 @@ rrn_sect_new_full ()
 	return sect;
 }
 
-RrnSectFull *
+static RrnSectFull *
 find_sect_full (RrnSectFull *start, char *id)
 {
 	RrnSectFull *ret = start;
@@ -391,7 +399,7 @@ find_sect_full (RrnSectFull *start, char *id)
 	return NULL;
 }
 
-void
+static void
 rrn_reg_add_sections_full (RrnRegFull *reg, RrnSectFull *sects)
 {
 	RrnSectFull *real_orphans = NULL;
@@ -424,7 +432,7 @@ rrn_reg_add_sections_full (RrnRegFull *reg, RrnSectFull *sects)
 	return;
 }
 
-int
+static int
 rrn_sects_add_sect_full (RrnSectFull *current, RrnSectFull *sect)
 {
 	char *cur_sect = NULL;
@@ -454,7 +462,7 @@ rrn_sects_add_sect_full (RrnSectFull *current, RrnSectFull *sect)
 	return 0;
 }
 
-int
+static int
 rrn_reg_add_sect_full (RrnRegFull *reg, RrnSectFull *sect)
 {
 	if (!sect->owner || !strcmp (reg->identifier, sect->owner)) {
@@ -569,7 +577,7 @@ rrn_sect_parse_file_full (char *filename)
     return orphaned_sections;
 }
 
-void
+static void
 process_sect_line_full (char *line, RrnSectFull *sect)
 {
 	char *ret = NULL;
@@ -598,7 +606,7 @@ process_sect_line_full (char *line, RrnSectFull *sect)
 
 }
 
-void
+static void
 process_sect_pair_full (RrnSectFull *sect, char *key, char *value)
 {
     char *lang = NULL;
@@ -619,7 +627,7 @@ process_sect_pair_full (RrnSectFull *sect, char *key, char *value)
     return;
 }
 
-char *
+static void
 process_path_full (RrnRegFull *reg)
 {
 	char *prefix = NULL;
@@ -649,7 +657,7 @@ process_path_full (RrnRegFull *reg)
 	}
 }
 
-char *
+static void
 process_section_path_full (RrnListEntry *owner_paths, RrnSectFull *section)
 {
 	char *tmp = NULL;
